@@ -1,12 +1,12 @@
 dcor<- function(x){
-########## Correlation distance between pais of objects ##################
+########## Correlation distance between pairs of objects ##################
 # Input:
 # x: data matrix
 #
 # Output:
 # d: distance matrix
 ###########################################################################
-    d <- sqrt(1-cor(x))
+    d <- sqrt(1-cor(t(x)))
     d <- as.dist(d)
     return(d)
 }
