@@ -14,57 +14,29 @@ nt <- dim(v_d)[1]
 k <- max(pert)
 if (is.null(dim(x_d))){dim(x_d) <- c(1, length(x_d))}
 nn <- dim(x_d)[1]
-atipico <- matrix(0,nt,1)
-
-
-
 
 vg <- vgeo(x_d, pert);
 
 
 delta <- deltas_simple(x_d,vg,pert)
 
+frec <- tabulate(pert)
 
-# Calculo de W para los individuos de xx/d_x
-
-TW <- matrix(0,nn,1)+999;
-for (l in 1:nn){   
-   
-    phi <- proxi_simple(x_d[l,],vg,pert)
-    
-    TW[l] <- estW_simple(vg,delta, phi)$Wvalue
-    
-}
-
+# Calculate W for individuals in xx/d_x
+phi_d <- apply(x_d, 1, proxi_simple, var=vg, pert=pert, frec=frec)
+TW <- apply(phi_d, 2, estW_simple, var=vg, delta= delta, Uout=FALSE)
 
 # Calculate  maxumum of  W for ind. in  xx
 M <- max(TW)
 
 ############################################
-# Calculate W for ind. in  v_d and evalutate whether is atypical or not
+# Calculate W for ind. in  v_d and evalutate whether it is atypical or not
+phi_x <- apply(v_d, 1, proxi_simple, var=vg, pert=pert, frec=frec)
+W0 <- apply(phi_x, 2, estW_simple, var=vg, delta= delta, Uout=FALSE)
 
-for (ind in 1:nt){
-    phi <- proxi_simple(v_d[ind,],vg,pert)
-    W0 <- estW_simple(vg,delta,phi)$Wvalue
-    
-    # Clasificacion en atipico o no atipico
-    
-    if (W0<=M){
-        atipico[ind] <-0
-    }
-    if (W0 > M){
-        atipico[ind] <-1
-    }
-    
-} #for ind=1:nt
+atipico <- ifelse(W0 <= M, 0, 1)
 
-
-contar <- 0 # To count atypical units in v_d
-contar <- sum(atipico)
-  
-
-#out <- list(Wx=TW, Ati=atipico, suma=contar)
-out<-contar
+out <- sum(atipico)
 
 return(out)
 
